@@ -2,7 +2,7 @@
 '''  ''is used too'''
 # this is zhushi  oo
 
-def print_lol (the_list,level):
+def print_lol (the_list,level=0):
     for each_item in the_list :
         if isinstance (each_item,list):
             print_lol (each_item,level+1)
